@@ -18,15 +18,16 @@
 #ifndef TERMINAL_ACCELS_H
 #define TERMINAL_ACCELS_H
 
+#include <gio/gio.h>
 #include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
-void terminal_accels_init (void);
+void terminal_accels_init (GSettings *settings);
  
 void terminal_accels_shutdown (void);
 
-void terminal_edit_keys_dialog_show (GtkWindow *transient_parent);
+void terminal_accels_fill_treeview (GtkWidget *treeview);
 
 G_END_DECLS
 
